@@ -21,6 +21,8 @@ from typing import Callable, Dict, Optional, Union
 
 from flwr.common import (
     GRPC_MAX_MESSAGE_LENGTH,
+    EventType,
+    event,
     ndarrays_to_parameters,
     parameters_to_ndarrays,
 )
@@ -128,6 +130,8 @@ def start_client(
     >>>     root_certificates=Path("/crts/root.pem").read_bytes(),
     >>> )
     """
+    event(EventType.START_CLIENT_ENTER)
+
     while True:
         sleep_duration: int = 0
         with grpc_connection(
@@ -156,6 +160,8 @@ def start_client(
         )
         time.sleep(sleep_duration)
 
+    event(EventType.START_CLIENT_LEAVE)
+
 
 def start_numpy_client(
     *,
