@@ -20,6 +20,8 @@ from .parameter import bytes_to_ndarray as bytes_to_ndarray
 from .parameter import ndarray_to_bytes as ndarray_to_bytes
 from .parameter import ndarrays_to_parameters as ndarrays_to_parameters
 from .parameter import parameters_to_ndarrays as parameters_to_ndarrays
+from .telemetry import EventType as EventType
+from .telemetry import event as event
 from .typing import ClientMessage as ClientMessage
 from .typing import Code as Code
 from .typing import Config as Config
@@ -51,6 +53,8 @@ __all__ = [
     "DisconnectRes",
     "EvaluateIns",
     "EvaluateRes",
+    "event",
+    "EventType",
     "FitIns",
     "FitRes",
     "GetParametersIns",
