@@ -32,19 +32,39 @@ class ClientManager(ABC):
 
     @abstractmethod
     def num_available(self) -> int:
-        """Return the number of available clients."""
+        """Return the number of available clients.
+
+        Returns
+        -------
+        num_available : int
+            The number of currently available clients.
+        """
 
     @abstractmethod
     def register(self, client: ClientProxy) -> bool:
         """Register Flower ClientProxy instance.
 
-        Returns:
-            bool: Indicating if registration was successful
+        Parameters
+        ----------
+        client : flwr.server.client_proxy.ClientProxy
+
+        Returns
+        -------
+        success : bool
+            Indicating if registration was successful. False if ClientProxy is
+            already registered or can not be registered for any reason.
         """
 
     @abstractmethod
     def unregister(self, client: ClientProxy) -> None:
-        """Unregister Flower ClientProxy instance."""
+        """Unregister Flower ClientProxy instance.
+
+        This method is idempotent.
+
+        Parameters
+        ----------
+        client : flwr.server.client_proxy.ClientProxy
+        """
 
     @abstractmethod
     def all(self) -> Dict[str, ClientProxy]:
@@ -74,27 +94,50 @@ class SimpleClientManager(ClientManager):
     def __len__(self) -> int:
         return len(self.clients)
 
-    def wait_for(self, num_clients: int, timeout: int = 86400) -> bool:
-        """Block until at least `num_clients` are available or until a timeout
-        is reached.
+    def num_available(self) -> int:
+        """Return the number of available clients.
 
-        Current timeout default: 1 day.
+        Returns
+        -------
+        num_available : int
+            The number of currently available clients.
+        """
+        return len(self)
+
+    def wait_for(self, num_clients: int, timeout: int = 86400) -> bool:
+        """Wait until at least `num_clients` are available.
+
+        Blocks until the requested number of clients is available or until a
+        timeout is reached. Current timeout default: 1 day.
+
+        Parameters
+        ----------
+        num_clients : int
+            The number of clients to wait for.
+        timeout : int
+            The time in seconds to wait for, defaults to 86400 (24h).
+
+        Returns
+        -------
+        success : bool
         """
         with self._cv:
             return self._cv.wait_for(
                 lambda: len(self.clients) >= num_clients, timeout=timeout
             )
 
-    def num_available(self) -> int:
-        """Return the number of available clients."""
-        return len(self)
-
     def register(self, client: ClientProxy) -> bool:
         """Register Flower ClientProxy instance.
 
-        Returns:
-            bool: Indicating if registration was successful. False if ClientProxy is
-                already registered or can not be registered for any reason
+        Parameters
+        ----------
+        client : flwr.server.client_proxy.ClientProxy
+
+        Returns
+        -------
+        success : bool
+            Indicating if registration was successful. False if ClientProxy is
+            already registered or can not be registered for any reason.
         """
         if client.cid in self.clients:
             return False
@@ -109,6 +152,10 @@ class SimpleClientManager(ClientManager):
         """Unregister Flower ClientProxy instance.
 
         This method is idempotent.
+
+        Parameters
+        ----------
+        client : flwr.server.client_proxy.ClientProxy
         """
         if client.cid in self.clients:
             del self.clients[client.cid]
