@@ -23,6 +23,7 @@ from .fedavg_android import FedAvgAndroid as FedAvgAndroid
 from .fedavgm import FedAvgM as FedAvgM
 from .fedmedian import FedMedian as FedMedian
 from .fedopt import FedOpt as FedOpt
+from .fedprox import FedProx as FedProx
 from .fedyogi import FedYogi as FedYogi
 from .qfedavg import QFedAvg as QFedAvg
 from .strategy import Strategy as Strategy
@@ -35,6 +36,7 @@ __all__ = [
     "FedAvgAndroid",
     "FedAvgM",
     "FedOpt",
+    "FedProx",
     "FedYogi",
     "QFedAvg",
     "FedMedian",
