@@ -32,10 +32,11 @@ from flwr.common import (
 from .fedavg import FedAvg
 
 
+# flake8: noqa: E501
 class FedOpt(FedAvg):
     """Configurable FedAdagrad strategy implementation."""
 
-    # pylint: disable=too-many-arguments,too-many-instance-attributes,too-many-locals
+    # pylint: disable=too-many-arguments,too-many-instance-attributes,too-many-locals,line-too-long
     def __init__(
         self,
         *,
@@ -68,39 +69,40 @@ class FedOpt(FedAvg):
 
         Parameters
         ----------
-        fraction_fit (float, optional): Fraction of clients used during
-            training. Defaults to 0.1.
-        fraction_evaluate (float, optional): Fraction of clients used during
-            validation. Defaults to 0.1.
-        min_fit_clients (int, optional): Minimum number of clients used
-            during training. Defaults to 2.
-        min_evaluate_clients (int, optional): Minimum number of clients used
-            during validation. Defaults to 2.
-        min_available_clients (int, optional): Minimum number of total
-            clients in the system. Defaults to 2.
-        evaluate_fn : Optional[
-            Callable[
-                [int, NDArrays, Dict[str, Scalar]],
-                Optional[Tuple[float, Dict[str, Scalar]]]
-            ]
-        ]: Function used for validation. Defaults to None.
-        on_fit_config_fn (Callable[[int], Dict[str, str]], optional):
+        fraction_fit : float, optional
+            Fraction of clients used during training. Defaults to 1.0.
+        fraction_evaluate : float, optional
+            Fraction of clients used during validation. Defaults to 1.0.
+        min_fit_clients : int, optional
+            Minimum number of clients used during training. Defaults to 2.
+        min_evaluate_clients : int, optional
+            Minimum number of clients used during validation. Defaults to 2.
+        min_available_clients : int, optional
+            Minimum number of total clients in the system. Defaults to 2.
+        evaluate_fn : Optional[Callable[[int, NDArrays, Dict[str, Scalar]], Optional[Tuple[float, Dict[str, Scalar]]]]]
+            Optional function used for validation. Defaults to None.
+        on_fit_config_fn : Callable[[int], Dict[str, Scalar]], optional
             Function used to configure training. Defaults to None.
-        on_evaluate_config_fn (Callable[[int], Dict[str, str]], optional):
+        on_evaluate_config_fn : Callable[[int], Dict[str, Scalar]], optional
             Function used to configure validation. Defaults to None.
-        accept_failures (bool, optional): Whether or not accept rounds
-            containing failures. Defaults to True.
-        initial_parameters (Parameters): Initial set of parameters from the server.
-        fit_metrics_aggregation_fn: Optional[MetricsAggregationFn]
+        accept_failures : bool, optional
+            Whether or not accept rounds containing failures. Defaults to True.
+        initial_parameters : Parameters, optional
+            Initial global model parameters.
+        fit_metrics_aggregation_fn : Optional[MetricsAggregationFn]
             Metrics aggregation function, optional.
         evaluate_metrics_aggregation_fn: Optional[MetricsAggregationFn]
             Metrics aggregation function, optional.
-        eta (float, optional): Server-side learning rate. Defaults to 1e-1.
-        eta_l (float, optional): Client-side learning rate. Defaults to 1e-1.
-        beta_1 (float, optional): Momentum parameter. Defaults to 0.0.
-        beta_2 (float, optional): Second moment parameter. Defaults to 0.0.
-        tau (float, optional): Controls the algorithm's degree of adaptability.
-            Defaults to 1e-9.
+        eta : float, optional
+            Server-side learning rate. Defaults to 1e-1.
+        eta_l : float, optional
+            Client-side learning rate. Defaults to 1e-1.
+        beta_1 : float, optional
+            Momentum parameter. Defaults to 0.0.
+        beta_2 : float, optional
+            Second moment parameter. Defaults to 0.0.
+        tau : float, optional
+            Controls the algorithm's degree of adaptability. Defaults to 1e-9.
         """
         super().__init__(
             fraction_fit=fraction_fit,
