@@ -29,7 +29,7 @@ To install the necessary dependencies, install `flwr` with the `simulation` extr
 """
 
     def start_simulation(*args, **kwargs):  # type: ignore
-        """Print error stating that ray is missing."""
+        """Log error stating that module `ray` could not be imported."""
         raise ImportError(RAY_IMPORT_ERROR)
 
 
